==> haskell-weigh-0.0.16-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-weigh.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 weigh
version:              0.0.16
visibility:           public
id:                   weigh-0.0.16-9tEqueBpTU184adPYo4VPL
key:                  weigh-0.0.16-9tEqueBpTU184adPYo4VPL
license:              BSD-3-Clause
copyright:            FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               Chris Done
homepage:             https://github.com/fpco/weigh#readme
synopsis:             Measure allocations of a Haskell functions/values
description:          Please see README.md
category:             Web
abi:                  4c58ff6bc1033fb1cfd61efde3f01610
exposed:              True
exposed-modules:      Weigh
hidden-modules:       Weigh.GHCStats
import-dirs:          /usr/lib/ghc-8.10.1/site-local/weigh-0.0.16
library-dirs:         /usr/lib/ghc-8.10.1/site-local/weigh-0.0.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/weigh-0.0.16
hs-libraries:         HSweigh-0.0.16-9tEqueBpTU184adPYo4VPL
depends:
    base-4.14.0.0 deepseq-1.4.4.0 ghc-8.10.1 mtl-2.2.2 process-1.6.8.2
    split-0.2.3.4-ByNr0H4GiIkqI7eEz5PIl
    temporary-1.3-FPmHKIJnX7EI2FnOsQxefl

haddock-interfaces:   /usr/share/doc/haskell-weigh/html/weigh.haddock
haddock-html:         /usr/share/doc/haskell-weigh/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-weigh-0.0.16-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-weigh.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 weigh
version:              0.0.16
visibility:           public
id:                   weigh-0.0.16-9i5QvXzQu6rIumUJ9SYmTK
key:                  weigh-0.0.16-9i5QvXzQu6rIumUJ9SYmTK
license:              BSD-3-Clause
copyright:            FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               Chris Done
homepage:             https://github.com/fpco/weigh#readme
synopsis:             Measure allocations of a Haskell functions/values
description:          Please see README.md
category:             Web
abi:                  8a3e9fa5b26a058466b594ef94ce9941
exposed:              True
exposed-modules:      Weigh
hidden-modules:       Weigh.GHCStats
import-dirs:          /usr/lib/ghc-8.10.1/site-local/weigh-0.0.16
library-dirs:         /usr/lib/ghc-8.10.1/site-local/weigh-0.0.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/weigh-0.0.16
hs-libraries:         HSweigh-0.0.16-9i5QvXzQu6rIumUJ9SYmTK
depends:
    base-4.14.0.0 deepseq-1.4.4.0 ghc-8.10.1 mtl-2.2.2 process-1.6.8.2
    split-0.2.3.4-I2Voq0QcJK5FrKDioOF6gT
    temporary-1.3-LeRCerT2C7kEhJJDBRA3NZ

haddock-interfaces:   /usr/share/doc/haskell-weigh/html/weigh.haddock
haddock-html:         /usr/share/doc/haskell-weigh/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
